pub fn install_admin_module_refresher(refresher: Arc<dyn AdminModuleRefresher>)Expand description
Install the callback used by the explicit admin refresh endpoint.
Kept as an injected seam so this platform crate does not depend on the composition root that knows how to load linked and remote modules.